@@ -2,32 +2,29 @@
 
 
 class BaseException(Exception):
-    pass
+    def __init__(self, message) -> None:
+        self.message = message
+
+    def __str__(self) -> str:
+        return self.message
 
 
 class MissingAWSEnvVar(BaseException):
     def __init__(self) -> None:
-        self.message = 'Missing AWS environment variables to configure access'
-
-    def __str__(self) -> str:
-        return self.message
+        super().__init__(
+            'Missing AWS environment variables to configure access')
 
 
 class InvalidPayload(BaseException):
     def __init__(self, missing_key: str, api_method: str):
-        self.message = f'Unexpected payload received, missing "{missing_key}" \
-from "{api_method}" call response'
-
-    def __str__(self) -> str:
-        return self.message
+        super().__init__(
+            f'Unexpected payload received, missing "{missing_key}" from \
+"{api_method}" call response')
 
 
 class ECRClientException(BaseException):
     def __init__(self, error_code: str, message: str):
         if error_code == 'RepositoryNotFoundException':
-            self.message = (message.split(':')[1].lstrip())
+            super().__init__(message.split(':')[1].lstrip())
         else:
-            self.message = message
-
-    def __str__(self) -> str:
-        return self.message
+            super().__init__(message)
